@@ -10,6 +10,10 @@ class IndicatorFillingTaskCreateContract(Contract):
     pass
 
 
+class IndicatorDescriptionReadContract(Contract):
+    name = serializers.CharField(max_length=128)
+
+
 class IndicatorReadContract(Contract):
     BAD = 'BAD'
     GOOD = 'GOOD'
@@ -18,7 +22,7 @@ class IndicatorReadContract(Contract):
         (GOOD, GOOD),
     )
     created = serializers.DateTimeField()
-    name = serializers.CharField(max_length=128)
+    description = IndicatorFillingTaskCreateContract()
     value = serializers.IntegerField(min_value=0)
     rate = serializers.ChoiceField(choices=RATE_CHOICES)
     recommendation = serializers.CharField(max_length=1024)
